"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        this.id_contractor = obj.id_contractor;
        this.name_contractor = obj.name_contractor;
        this.email_contractor = obj.email_contractor;
        this.address_contractor = obj.address_contractor;
        this.phone_contractor = obj.phone_contractor;
        this.id_product = obj.id_product;
        this.name_product = obj.name_product;
        this.choice_packaging = obj.choice_packaging;
    }
    static getOne(id_contractor) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `contractor` WHERE `id_contractor` = :id_contractor", {
                id_contractor,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `contractor` ORDER BY `name_contractor`');
            return results;
        });
    }
    static getAllProduct(id_contractor) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `id_product`,`name_product`, `choice_packaging` FROM `products` WHERE `id_contractor` = :id_contractor", { id_contractor });
            return results;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id_contractor) {
                this.id_contractor = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already inserted');
            }
            yield db_1.pool.execute('INSERT INTO `contractor` (`id_contractor`, `name_contractor`, `email_contractor`, `address_contractor`, `phone_contractor`) VALUES (:id_contractor, :name_contractor, :email_contractor, :address_contractor, :phone_contractor)', this);
        });
    }
    insertProduct() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id_product) {
                this.id_product = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already inserted');
            }
            yield db_1.pool.execute("INSERT INTO `products` (`id_product`, `name_product`, `choice_packaging`, `id_contractor`) VALUES (:id_product, :name_product, :choice_packaging,  :id_contractor)", this);
        });
    }
    static delete(id_contractor) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("DELETE FROM `contractor` WHERE `id_contractor`  = :id_contractor", {
                id_contractor,
            });
            return results;
        });
    }
    static deleteProduct(id_product) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("DELETE FROM `products` WHERE `id_product`  = :id_product", {
                id_product,
            });
            return results;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("UPDATE `contractor` SET `name_contractor`= :name_contractor, `email_contractor` = :email_contractor, `address_contractor` = :address_contractor, `phone_contractor` = :phone_contractor WHERE `id_contractor`  = :id_contractor", this);
            return results;
        });
    }
    updateProduct() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("UPDATE `products` SET `name_product`= :name_product, `choice_packaging` = :choice_packaging  WHERE `id_product` = :id_product", this);
            return results;
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map